import 'package:flutter/services.dart';

import 'basesharebean.dart';
import 'baseshareplugin.dart';

class Qyshare {
  static const MethodChannel _channel =
      const MethodChannel('flutter.qiyi.com/share');

  static BaseSharePlugin qqShare;
  static BaseSharePlugin wechatShare;
  static BaseSharePlugin wbShare;

  static void addBaseSharePlugin(
      BaseSharePlugin sharePlugin, String sharePluginType) {
    if (sharePlugin == null) {
      throw ("sharePlugin must not be null");
    }
    switch (sharePluginType) {
      case BaseShareBean.PLATFORM_QQ:
      case BaseShareBean.PLATFORM_QZONE:
        qqShare = sharePlugin;
        break;
      case BaseShareBean.PLATFORM_WB:
        wbShare = sharePlugin;
        break;
      case BaseShareBean.PLATFORM_WX:
      case BaseShareBean.PLATFORM_WX_pyq:
        wechatShare = sharePlugin;
        break;
      default:
        throw ("unkown sharePlugin");
    }
  }

  static Future<dynamic> share(BaseShareBean sb) {
    if (sb == null) {
      throw ("sharebean must not be null");
    } else if (sb.platform == null) {
      throw ("platform of sharebean must not be null");
    }
    switch (sb.platform) {
      case BaseShareBean.PLATFORM_QQ:
      case BaseShareBean.PLATFORM_QZONE:
        return shareImplementer(qqShare, sb);
        break;
      case BaseShareBean.PLATFORM_WB:
        return shareImplementer(wbShare, sb);
        break;
      case BaseShareBean.PLATFORM_WX:
      case BaseShareBean.PLATFORM_WX_pyq:
        return shareImplementer(wechatShare, sb);
        break;
    }
    throw ("unknow platform");
  }

  static Future<dynamic> shareImplementer(
      BaseSharePlugin shareplugin, BaseShareBean sb) {
    if (sb.shareType == null) {
      throw ("sharetype must not be null");
    }
    switch (sb.shareType) {
      case BaseShareBean.SHARETYPE_DEFAULT:
        return shareplugin.shareWebPage(sb);
      case BaseShareBean.SHARETYPE_FILE:
        return shareplugin.shareFile(sb);
      case BaseShareBean.SHARETYPE_TEXT:
        return shareplugin.shareText(sb);
      case BaseShareBean.SHARETYPE_VIDEO:
        return shareplugin.shareVideo(sb);
      case BaseShareBean.SHARETYPE_PIC:
        return shareplugin.sharePic(sb);
      case BaseShareBean.SHARETYPE_MINIPROGRAMME:
        return shareplugin.shareMiniProgram(sb);
    }
    throw ("unkown sharetype");
  }
}
